# vim: set ts=4 sw=4 et:
#
# spec file for package rapid-photo-downloader
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Togan Muftuoglu toganm@opensuse.org
# Copyright (c) 2009-2011 Pascal Blesser pascal.bleser@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rapid-photo-downloader
Version:        0.4.10
Release:        5.6
Summary:        Rapid Photo Downloader
License:        GPL-2.0+
Group:          Productivity/Graphics/Other
Url:            http://damonlynch.net/rapid/
Source:         http://launchpad.net/rapid/trunk/%{version}/+download/rapid-photo-downloader-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif
Requires:       dbus-1-python
%if 0%{?suse_version} <= 1210
Requires:       exiftool
%else
Requires:       perl-Image-ExifTool
%endif
Requires:       exiftran
Requires:       gdk-pixbuf-loader-rsvg
Requires:       python-gconf
Requires:       python-gnome
Requires:       python-gobject2
Requires:       python-gtk
Requires:       python-imaging
Requires:       python-notify
Requires:       python-pyexiv2
%py_requires

%description
Rapid Photo Downloader for Linux is written by a photographer for professional
and amateur photographers. Its goal is to be the best photo downloader for the
Linux Desktop. It is free software, released under the GNU GPL license.

%prep
%setup -q
rm rapid/*test.py

pushd rapid
find . -type f -name '*.py' -exec sed -i -e '/^#!\//, 1d' {} \;
popd #rapid

cp  rapid/{ChangeLog,COPYING,AUTHORS} .
pod2man --section=1 -u --release=%version  --center "" doc/rapid-photo-downloader.pod > %name.1

%build
python ./setup.py build

%install
python ./setup.py install \
    --prefix="%{_prefix}" \
    --root=%{buildroot} \
    --record-rpm=files.lst

d="%{_datadir}"
d="${d#/}"
d="${d%/}"

perl -ni -e 'print unless m,^%dir\s+/?'"$d"'/(applications|pixmaps|icons)$,' files.lst
perl -ni -e 'print unless m|.*/LC_MESSAGES/.*|' files.lst

%find_lang rapid-photo-downloader

cat rapid-photo-downloader.lang files.lst > rpmfiles

%suse_update_desktop_file -r rapid-photo-downloader Graphics Photography

chmod 0755 "%{buildroot}%{_bindir}/rapid-photo-downloader"
perl -ni -e 'print unless m|^%{_bindir}|' rpmfiles
install -d %buildroot/%_mandir/man1
install -m 644 %name.1 %buildroot/%_mandir/man1/

%fdupes -s %buildroot

%files -f rpmfiles
%defattr(-,root,root)
%doc README ChangeLog AUTHORS COPYING
%attr(0755,root,root) %{_bindir}/rapid-photo-downloader
%_mandir/man1/%name.1.gz

%changelog
* Tue Mar  4 2014 toganm@opensuse.org
- Update to 0.4.10 For details see Changelog
  * Updated Catalan and Portuguese translations.
  * Fixed bug in translations for term "Back up".
* Tue Jan 28 2014 toganm@opensuse.org
- Update to 0.4.9 For details see Changelog
  * Updated Catalan and Spanish and Swedish translations.
  * Fixed occasional incorrect use of term "backup".
* Wed Jan 15 2014 toganm@opensuse.org
- Update to 0.4.8 For details see Changelog
  * Fixed bug lp#1263237: Added support for MPO files (3D images).
  * Fixed bug lp#1263483: Some terms in the user interface are not
    being translated.
  * Updated Dutch, French Italian, Polish and Spanish translations.
* Thu Oct 24 2013 toganm@opensuse.org
- Update to 0.4.7 For details see Changelog
  * Added feature to download audio files that are associated with
    photos such as those created by the Canon 1D series of cameras.
  * Fixed bug #1242119: In Ubuntu 13.10, choosing a destination or
    source folder from its bookmark does not work. The correct value
    is displayed in the file chooser button, but this value is not
    used by Rapid Photo Downloader. Earlier versions of Ubuntu were
    unaffected.
  * Fixed bug #1206853: Crashes when system message notifications not
    functioning properly.
  * Fixed bug #909405: Allow selections by row (and not GTK default
    by square) when user is dragging the mouse or using the keyboard
    to select.
  * Added a KDE Solid action. Solid is KDE4's hardware-related
    framework. It detects when the user connects a new device and
    display a list of related actions. Thanks to dju` for the patch.
  * Added Belarusian translation—thanks go to Ilya Tsimokhin. Updated
    Swedish and Ukrainian translations.
* Thu Jan 24 2013 toganm@opensuse.org
- Update to 0.4.6 For details see Changelog
  * Fixed bug lp#1083756: Application shows duplicate sources.
  * Fixed bug lp#1093330: Photo rename ignores SubSeconds when 00.
  * Updated German and Spanish translations.
  * Added extra debugging output to help trace program execution
    progress.
- added fdupes to buildrequires to fix duplicate files
* Thu Jul  5 2012 toganm@opensuse.org
- removed man page compression as rpm does this byitself
* Wed Jul  4 2012 toganm@opensuse.org
- Update to 0.4.5 For details see Changelog
  * Updated Dutch, Estonian, German, Italian, Norwegian and Polish
    translations.
  * Updated man page.
  * Fixed bug #1014203: Very poor program performance after download
    device changed. The program now displays the results of scanning
    files much quicker if the program's download device preferences
    are changed and a scan begins of a new device.
  * Fixed bug #1014219: File Modify process crashes if program exits
    during download.
* Wed May 30 2012 toganm@opensuse.org
- Update to 0.4.4 For details see Changelog
  * Fixed bug #998320: Applied patch from Dmitry Kazimirov for
    option to have subfolder generation and file renaming use a
    month in text format.
  * Fixed bug #986681: Crash when showing question dialog on some
    non-Gnome systems.
  * Fixed bug #995769: The Help button in the preferences dialog
    does not work.
  * Fixed bug #996613: Updated Free Software Foundation address.
  * Added Estonian translation. Updated Brazilian, Dutch, French,
    German, Norwegian Bokmal, Polish, Spanish and Russian
    translations.
* Tue May  8 2012 toganm@opensuse.org
- add perl-Image-ExifTool gdk-pixbuf-loader-rsvg to requires
* Tue May  1 2012 toganm@opensuse.org
- update to 0.4.3 For details see ChangeLog :
  * ExifTool is now a required dependency for Rapid Photo Downloader.
    ExifTool can be used to help download videos on Linux distributions
    that have not packaged hachoir-metadata.
  * Exiftran is another new dependency. It is used to automatically
    rotate JPEG images.
  * Fixed bug #704482: Delete photos option should be easily accessible
  * Fixed bug #754531: extract Exif.CanonFi.FileNumber metadata
  * Fixed bug #695517: Added functionality to download MTS video files.
  * Fixed bug #859998: Download THM video thumbnail files
  * Fixed bug #594533: Lossless JPEG rotation based on EXIF data after
    picture transfer
  * Fixed bug #859012: Confirm if really want to download from /home,
    /media or /
- Use the original source files
- Follow openSUSE license format
- Include ChangeLog AUTHORS COPYING in the docs
- Use license for the spec itself
* Fri Apr 29 2011 pascal.bleser@opensuse.org
- update to 0.4.0:
  * clean new user interface
  * imports about 3 times faster
  * ability to select multiple files to check or uncheck for downloading
  * adds automation feature to delete downloaded files from a device
  * backups have been implemented
  * adds a preferences option for disabling thumbnail generation
  * fixes a crash that occurred when downloading some files after having
    previously downloaded others in the same session
  * adds Job Code functionality
  * adds an eject device button for each unmountable device
  * adds display of remaining files to be downloaded in the progress bar
  * adds display of overall download progress in the lower progress bar
  * adds display of time remaining and download speed in the status bar
  * adds system notification messages
  * adds new automation features: auto download, auto exit, and auto unmount
  * bugfix: display file and subfolder naming warnings in error log
  * adds an error log window to display download warnings and errors
  * adds a feature to synchronize RAW + JPEG sequence values
* Fri Mar 25 2011 pascal.bleser@opensuse.org
- update to 0.3.5:
  * fix bug #714039, where under certain circumstances the program could crash
    while downloading files
  * added Romanian translation. Updated Brazilian, Chinese, Croatian, Czech,
    Dutch, Finnish, German, Italian, Polish and Russian translations
* Sun Jan  2 2011 pascal.bleser@opensuse.org
- update to 0.3.4:
  * you can now zoom in and out of a preview image
  * extraneous white space is now more effectively stripped from serial number metadata and folder names
  * a Croatian translation was added
  * the French, Norwegian Bokmal, Polish, and Russian translations were updated
  * other minor fixes were made
* Wed Oct 27 2010 pascal.bleser@opensuse.org
- update to 0.3.3:
  * adds support for mod, tod, and 3gp video files
  * adds preliminary support for Samusung SRW files
  * generation of subfolders and filenames using the time a download was started
  * hachoir-metadata is now used to extract selected metadata from video files
  * fixes for bugs related to a missing video download directory at program startup
  * a command line option to output to the terminal information, which is useful for debugging
  * Norwegian Bokmal and Portuguese translations
  * updates to many other translations
* Mon Sep 13 2010 pascal.bleser@opensuse.org
- update to 0.3.2:
  * adds a Norwegian Nynorsk translation
  * updates the Chinese, Finnish, Hungarian, Dutch, Occitan (post 1500), Polish, Brazilian Portuguese, and Russian translations
  * fixes crash on startup when checking for free space and the download folder does not exist
* Fri Aug 13 2010 pascal.bleser@opensuse.org
- update to 0.3.1:
  * main window now works more effectively on tiny screens like netbooks
  * amount of free space available on the filesystem where photos are to be downloaded is now displayed in the status bar
  * added or updated many translations: Chinese (simplified), Bulgarian, Japanese, Occitan (post 1500), Persian, Portuguese (Brazilian), and Turkish have been added; updated Finnish, French, Hungarian, Russian, Serbian and Spanish translations
* Sun Jul 11 2010 pascal.bleser@opensuse.org
- update to 0.3.0:
  * the major new feature of this release is the generation of previews before a download takes place: you can now select which photos and videos you wish to download
  * you can now assign different job codes to photos and videos in the same download: simply select photos and videos, and from the main window choose a job code for them
  * the errors and warnings reported have been completely overhauled, and are now more concise
* Mon Jun  7 2010 pascal.bleser@opensuse.org
- update to 0.2.2:
  * adds an Ukranian translation
  * no longer crashes on startup when exiv2 is not installed
* Sun Jun  6 2010 pascal.bleser@opensuse.org
- update to 0.2.1:
  * Bug fix: display sample photo and video names in preferences
    dialog using first photo and video found on download device,
    where possible -- this used to work but was inadvertently
    disabled in a recent release
  * Bug fix: prompt for Job code when only video names or video
    subfolder names use a job code
  * bug fix: filter out Null bytes from Exif string values -- these
    can occur when the Exif data is corrupted
  * translation updates for Spanish, Russian and Finnish
* Mon May 31 2010 pascal.bleser@opensuse.org
- update to 0.2.0:
  * video download functionality was added
  * the use of version 0.2.x of the pyexiv2 library was enabled
  * a bug in which sometimes images could not be downloaded to NTFS
    partitions was fixed
  * error message headings in the Error Log are now displayed in a
    red font
  * program settings and preferences can be reset using a new
    command line option
* Sun Feb 14 2010 pascal.bleser@opensuse.org
- update to 0.1.3:
  * fixed bug #509348: when both the backup and "Delete images
    from image device upon download completion" options are
    selected, the program will only delete an image from the image
    device if it was both downloaded to the download folder and
    backed up; previously it did not check to ensure it was backed
    up correctly too
  * fixed bug #505492: the program previously failed to start in
    environments where the notification system has problems
  * fixed bug #508304: the user is now prompted to confirm if they
    really want to remove all of their Job Codes after clicking on
    "Remove All" in the preferences dialog window
  * fixed bug #510484: previously, the program could crash when
    attempting to download to a read-only folder
  * fixed bug #510516: the program now checks to see if the
    download folder exists and is writeable; if automatic detection
    of image devices is not enabled, it checks to see if the image
    location path exists
- changes from 0.1.2:
  * new feature: photographers using RAW + JPEG mode now have the
    option to synchronize sequence numbers for the matching pair
    of images: this option is useful if you use the RAW + JPEG
    feature on your camera and you use sequence numbers or letters
    in your image renaming; enabling this option will cause the
    program to detect matching pairs of RAW and JPEG images, and
    when they are detected, the same sequence numbers and letters
    will be applied to both image names; furthermore, sequences
    will be updated as if the images were one
  * increased maximum sequence number length to seven digits by
    user request
  * fixed bug #503704: changes in values for downloads today and
    stored number not updated when changed via program preferences
    while a download is ready to begin
- changes from 0.1.1:
  * aded auto delete feature. When enabled, upon the completion of
    a download, images that were successfully downloaded will be
    deleted from the image device they were downloaded from;
    images that were not downloaded successfully will not be
    deleted
  * added keyboard accelerators for Preferences and Help
- changes from 0.1.0:
  * added icons to notification messages
  * bug fix: properly handle devices being unmounted, fixing a bug
    introduced in Version 0.0.9 beta 2
  * bug fix: when program preferences are changed, image and backup
    devices are now refreshed only when the preferences dialog
    window is closed
  * bug fix: minutes component of image and folder renaming had the
    same code as months
  * fixed bug #484432: error in adding job codes via the
    preferences dialog
  * fixed bug #486886: job code prompt can appear multiple times
  * added a "Job codes" option
  * added additional hour, minute and second options in image
    renaming and subfolder creation
  * fixed bug #478620: problem with corrupted image files
  * fixed bug #479424: some camera model names do not have numbers,
    but it still makes sense to return a shortened name
  * fixed bug #482831: program no longer crashes when auto-download
    is off, and a device is inserted before another download has
    completed
* Sat Oct 17 2009 pascal.bleser@opensuse.org
- initial package: 0.0.10
